# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/Workflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn.v07 import Results_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)buffers/protobuf/workflows/Workflow.proto\x12\x1a\x62uffers.protobuf.workflows\x1a%buffers/protobuf/nn/v07/Results.proto\"J\n\x0bPredictions\x12;\n\x0bpredictions\x18\x01 \x03(\x0b\x32&.buffers.protobuf.workflows.Prediction\"A\n\nPrediction\x12\x10\n\x08label_id\x18\x01 \x01(\r\x12\x12\n\nlabel_name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\"<\n\x04\x46ile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x11\n\tmime_type\x18\x03 \x01(\t\"\xff\x01\n\x07\x43oncept\x12\x0f\n\x05image\x18\x01 \x01(\x0cH\x00\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x10\n\x06number\x18\x03 \x01(\x01H\x00\x12>\n\x0bpredictions\x18\x04 \x01(\x0b\x32\'.buffers.protobuf.workflows.PredictionsH\x00\x12\x34\n\x06region\x18\x05 \x01(\x0b\x32\".buffers.protobuf.workflows.RegionH\x00\x12\x11\n\x07\x62oolean\x18\x06 \x01(\x08H\x00\x12\x30\n\x04\x66ile\x18\x07 \x01(\x0b\x32 .buffers.protobuf.workflows.FileH\x00\x42\x06\n\x04type\"\xe9\x01\n\x06Region\x12\x31\n\x03roi\x18\x01 \x01(\x0b\x32$.buffers.protobuf.nn.v07.results.ROI\x12\x42\n\x08\x63oncepts\x18\x02 \x03(\x0b\x32\x30.buffers.protobuf.workflows.Region.ConceptsEntry\x12\x12\n\nentry_name\x18\x03 \x01(\t\x1aT\n\rConceptsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept:\x02\x38\x01\"{\n\x10WorkflowDataItem\x12\x32\n\x05\x65ntry\x18\x01 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept\x12\x33\n\x07regions\x18\x02 \x03(\x0b\x32\".buffers.protobuf.workflows.Region\"\xc2\x02\n\rFlowContainer\x12R\n\rworkflow_data\x18\x01 \x03(\x0b\x32;.buffers.protobuf.workflows.FlowContainer.WorkflowDataEntry\x12I\n\x08metadata\x18\x02 \x03(\x0b\x32\x37.buffers.protobuf.workflows.FlowContainer.MetadataEntry\x1a\x61\n\x11WorkflowDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.buffers.protobuf.workflows.WorkflowDataItem:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x07Outcome\x12\x35\n\x08\x63oncepts\x18\x01 \x03(\x0b\x32#.buffers.protobuf.workflows.Concept\x12\x33\n\x07regions\x18\x02 \x03(\x0b\x32\".buffers.protobuf.workflows.Regionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.Workflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGION_CONCEPTSENTRY._options = None
  _REGION_CONCEPTSENTRY._serialized_options = b'8\001'
  _FLOWCONTAINER_WORKFLOWDATAENTRY._options = None
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_options = b'8\001'
  _FLOWCONTAINER_METADATAENTRY._options = None
  _FLOWCONTAINER_METADATAENTRY._serialized_options = b'8\001'
  _PREDICTIONS._serialized_start=112
  _PREDICTIONS._serialized_end=186
  _PREDICTION._serialized_start=188
  _PREDICTION._serialized_end=253
  _FILE._serialized_start=255
  _FILE._serialized_end=315
  _CONCEPT._serialized_start=318
  _CONCEPT._serialized_end=573
  _REGION._serialized_start=576
  _REGION._serialized_end=809
  _REGION_CONCEPTSENTRY._serialized_start=725
  _REGION_CONCEPTSENTRY._serialized_end=809
  _WORKFLOWDATAITEM._serialized_start=811
  _WORKFLOWDATAITEM._serialized_end=934
  _FLOWCONTAINER._serialized_start=937
  _FLOWCONTAINER._serialized_end=1259
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_start=1113
  _FLOWCONTAINER_WORKFLOWDATAENTRY._serialized_end=1210
  _FLOWCONTAINER_METADATAENTRY._serialized_start=1212
  _FLOWCONTAINER_METADATAENTRY._serialized_end=1259
  _OUTCOME._serialized_start=1261
  _OUTCOME._serialized_end=1378
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Results.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Image_pb2 as buffers_dot_protobuf_dot_common_dot_Image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%buffers/protobuf/nn/v07/Results.proto\x12\x1f\x62uffers.protobuf.nn.v07.results\x1a#buffers/protobuf/common/Image.proto\"\x83\x01\n\tInference\x12\x42\n\x07tensors\x18\x01 \x03(\x0b\x32\x31.buffers.protobuf.nn.v07.results.Inference.Tensor\x1a\x32\n\x06Tensor\x12\x0c\n\x04\x64ims\x18\x01 \x03(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x02\x12\x0c\n\x04name\x18\x03 \x01(\t\"g\n\x04Mask\x12+\n\x04\x62\x62ox\x18\x01 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBox\x12\x32\n\x08polygons\x18\x02 \x03(\x0b\x32 .buffers.protobuf.common.Polygon\"\x86\x01\n\x03ROI\x12\x11\n\tregion_id\x18\x01 \x01(\r\x12-\n\x04\x62\x62ox\x18\x03 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBoxH\x00\x12\x35\n\x04mask\x18\x04 \x01(\x0b\x32%.buffers.protobuf.nn.v07.results.MaskH\x00\x42\x06\n\x04type\"\xb2\x02\n\x0cLabelsOutput\x12K\n\tpredicted\x18\x01 \x03(\x0b\x32\x38.buffers.protobuf.nn.v07.results.LabelsOutput.Prediction\x12K\n\tdiscarded\x18\x02 \x03(\x0b\x32\x38.buffers.protobuf.nn.v07.results.LabelsOutput.Prediction\x1a\x87\x01\n\nPrediction\x12\x10\n\x08label_id\x18\x01 \x01(\r\x12\x12\n\nlabel_name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12\x31\n\x03roi\x18\x05 \x01(\x0b\x32$.buffers.protobuf.nn.v07.results.ROI\")\n\x0cScalarOutput\x12\x11\n\x07integer\x18\x01 \x01(\x04H\x00\x42\x06\n\x04type\"N\n\nTextOutput\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nmean_score\x18\x02 \x01(\x02\x12\x0e\n\x06tokens\x18\x03 \x03(\t\x12\x0e\n\x06scores\x18\x04 \x03(\x02\"\xd7\x01\n\x0eRecognitionMix\x12?\n\x06labels\x18\x01 \x01(\x0b\x32-.buffers.protobuf.nn.v07.results.LabelsOutputH\x00\x12?\n\x06scalar\x18\x02 \x01(\x0b\x32-.buffers.protobuf.nn.v07.results.ScalarOutputH\x00\x12;\n\x04text\x18\x03 \x01(\x0b\x32+.buffers.protobuf.nn.v07.results.TextOutputH\x00\x42\x06\n\x04type\"O\n\x0bRecognition\x12@\n\x07outputs\x18\x01 \x03(\x0b\x32/.buffers.protobuf.nn.v07.results.RecognitionMixb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Results_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INFERENCE._serialized_start=112
  _INFERENCE._serialized_end=243
  _INFERENCE_TENSOR._serialized_start=193
  _INFERENCE_TENSOR._serialized_end=243
  _MASK._serialized_start=245
  _MASK._serialized_end=348
  _ROI._serialized_start=351
  _ROI._serialized_end=485
  _LABELSOUTPUT._serialized_start=488
  _LABELSOUTPUT._serialized_end=794
  _LABELSOUTPUT_PREDICTION._serialized_start=659
  _LABELSOUTPUT_PREDICTION._serialized_end=794
  _SCALAROUTPUT._serialized_start=796
  _SCALAROUTPUT._serialized_end=837
  _TEXTOUTPUT._serialized_start=839
  _TEXTOUTPUT._serialized_end=917
  _RECOGNITIONMIX._serialized_start=920
  _RECOGNITIONMIX._serialized_end=1135
  _RECOGNITION._serialized_start=1137
  _RECOGNITION._serialized_end=1216
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from deepomatic.rpc.buffers.protobuf.workflows import WorkflowExecution_pb2 as buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2


class WorkflowExecutorStub(object):
    """To generate gRPC server and client in deepomatic-workflows
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteWorkflow = channel.unary_unary(
                '/buffers.protobuf.workflows.WorkflowExecutor/ExecuteWorkflow',
                request_serializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.SerializeToString,
                response_deserializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.FromString,
                )
        self.ExecuteWorkflowStream = channel.stream_stream(
                '/buffers.protobuf.workflows.WorkflowExecutor/ExecuteWorkflowStream',
                request_serializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.SerializeToString,
                response_deserializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.FromString,
                )


class WorkflowExecutorServicer(object):
    """To generate gRPC server and client in deepomatic-workflows
    """

    def ExecuteWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteWorkflowStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowExecutorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExecuteWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteWorkflow,
                    request_deserializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.FromString,
                    response_serializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.SerializeToString,
            ),
            'ExecuteWorkflowStream': grpc.stream_stream_rpc_method_handler(
                    servicer.ExecuteWorkflowStream,
                    request_deserializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.FromString,
                    response_serializer=buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'buffers.protobuf.workflows.WorkflowExecutor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkflowExecutor(object):
    """To generate gRPC server and client in deepomatic-workflows
    """

    @staticmethod
    def ExecuteWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buffers.protobuf.workflows.WorkflowExecutor/ExecuteWorkflow',
            buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.SerializeToString,
            buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteWorkflowStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/buffers.protobuf.workflows.WorkflowExecutor/ExecuteWorkflowStream',
            buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowRequest.SerializeToString,
            buffers_dot_protobuf_dot_workflows_dot_WorkflowExecution__pb2.WorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/common/Image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#buffers/protobuf/common/Image.proto\x12\x17\x62uffers.protobuf.common\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\">\n\x04\x42\x42ox\x12\x0c\n\x04xmin\x18\x01 \x01(\x02\x12\x0c\n\x04xmax\x18\x02 \x01(\x02\x12\x0c\n\x04ymin\x18\x03 \x01(\x02\x12\x0c\n\x04ymax\x18\x04 \x01(\x02\"9\n\x07Polygon\x12.\n\x06points\x18\x01 \x03(\x0b\x32\x1e.buffers.protobuf.common.Pointb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.common.Image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POINT._serialized_start=64
  _POINT._serialized_end=93
  _BBOX._serialized_start=95
  _BBOX._serialized_end=157
  _POLYGON._serialized_start=159
  _POLYGON._serialized_end=216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Workflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'buffers/protobuf/nn/v07/Workflows.proto\x12!buffers.protobuf.nn.v07.workflows\"}\n\x08\x43onsumer\x12@\n\x04\x61mqp\x18\x01 \x01(\x0b\x32\x30.buffers.protobuf.nn.v07.workflows.Consumer.AMQPH\x00\x1a\'\n\x04\x41MQP\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\tB\x06\n\x04type\"\x82\x02\n\x0eTransformation\x12L\n\x07network\x18\x01 \x01(\x0b\x32\x39.buffers.protobuf.nn.v07.workflows.Transformation.NetworkH\x00\x12T\n\x0brecognition\x18\x02 \x01(\x0b\x32=.buffers.protobuf.nn.v07.workflows.Transformation.RecognitionH\x00\x1a\x1d\n\x07Network\x12\x12\n\nnetwork_id\x18\x01 \x01(\x05\x1a%\n\x0bRecognition\x12\x16\n\x0erecognition_id\x18\x01 \x01(\x05\x42\x06\n\x04type\"\xa3\x01\n\x08Workflow\x12\x0c\n\x04name\x18\x01 \x01(\t\x12=\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32+.buffers.protobuf.nn.v07.workflows.Consumer\x12J\n\x0ftransformations\x18\x03 \x03(\x0b\x32\x31.buffers.protobuf.nn.v07.workflows.Transformation\"K\n\tWorkflows\x12>\n\tworkflows\x18\x01 \x03(\x0b\x32+.buffers.protobuf.nn.v07.workflows.Workflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Workflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSUMER._serialized_start=78
  _CONSUMER._serialized_end=203
  _CONSUMER_AMQP._serialized_start=156
  _CONSUMER_AMQP._serialized_end=195
  _TRANSFORMATION._serialized_start=206
  _TRANSFORMATION._serialized_end=464
  _TRANSFORMATION_NETWORK._serialized_start=388
  _TRANSFORMATION_NETWORK._serialized_end=417
  _TRANSFORMATION_RECOGNITION._serialized_start=419
  _TRANSFORMATION_RECOGNITION._serialized_end=456
  _WORKFLOW._serialized_start=467
  _WORKFLOW._serialized_end=630
  _WORKFLOWS._serialized_start=632
  _WORKFLOWS._serialized_end=707
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn.v07 import Commands_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Commands__pb2
from deepomatic.rpc.buffers.protobuf.nn.v07 import Inputs_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Inputs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!buffers/protobuf/nn/Command.proto\x12\x13\x62uffers.protobuf.nn\x1a&buffers/protobuf/nn/v07/Commands.proto\x1a$buffers/protobuf/nn/v07/Inputs.proto\"\xe8\x01\n\nCommandMix\x12\x44\n\rv07_inference\x18\x04 \x01(\x0b\x32+.buffers.protobuf.nn.v07.commands.InferenceH\x00\x12H\n\x0fv07_recognition\x18\x05 \x01(\x0b\x32-.buffers.protobuf.nn.v07.commands.RecognitionH\x00\x12\x42\n\x0cv07_workflow\x18\x06 \x01(\x0b\x32*.buffers.protobuf.nn.v07.commands.WorkflowH\x00\x42\x06\n\x04type\"P\n\x08InputMix\x12<\n\nv07_inputs\x18\x02 \x01(\x0b\x32&.buffers.protobuf.nn.v07.inputs.InputsH\x00\x42\x06\n\x04type\"\x12\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\x05\"}\n\x0b\x43ommandInfo\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_pk\x18\x02 \x01(\x05\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x11\n\tdate_plan\x18\x04 \x01(\t\x12\x15\n\rcurrent_queue\x18\x05 \x01(\r\x12\x12\n\nforward_to\x18\x06 \x03(\t\"\xcf\x01\n\x07\x43ommand\x12\'\n\x04task\x18\x01 \x01(\x0b\x32\x19.buffers.protobuf.nn.Task\x12\x33\n\tbase_info\x18\x02 \x01(\x0b\x32 .buffers.protobuf.nn.CommandInfo\x12\x34\n\x0b\x63ommand_mix\x18\x05 \x01(\x0b\x32\x1f.buffers.protobuf.nn.CommandMix\x12\x30\n\tinput_mix\x18\x06 \x01(\x0b\x32\x1d.buffers.protobuf.nn.InputMixb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMANDMIX._serialized_start=137
  _COMMANDMIX._serialized_end=369
  _INPUTMIX._serialized_start=371
  _INPUTMIX._serialized_end=451
  _TASK._serialized_start=453
  _TASK._serialized_end=471
  _COMMANDINFO._serialized_start=473
  _COMMANDINFO._serialized_end=598
  _COMMAND._serialized_start=601
  _COMMAND._serialized_end=808
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/WorkOrder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*buffers/protobuf/workflows/WorkOrder.proto\x12\x1a\x62uffers.protobuf.workflows\"\xbb\x02\n\rWorkOrderData\x12I\n\x08metadata\x18\x01 \x03(\x0b\x32\x37.buffers.protobuf.workflows.WorkOrderData.MetadataEntry\x12\x45\n\x06states\x18\x02 \x03(\x0b\x32\x35.buffers.protobuf.workflows.WorkOrderData.StatesEntry\x12\r\n\x05types\x18\x03 \x03(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aX\n\x0bStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).buffers.protobuf.workflows.WorkItemState:\x02\x38\x01\"\xa5\x01\n\rWorkItemState\x12P\n\x0cstate_values\x18\x01 \x03(\x0b\x32:.buffers.protobuf.workflows.WorkItemState.StateValuesEntry\x12\x0e\n\x06memory\x18\x02 \x01(\t\x1a\x32\n\x10StateValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.WorkOrder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKORDERDATA_METADATAENTRY._options = None
  _WORKORDERDATA_METADATAENTRY._serialized_options = b'8\001'
  _WORKORDERDATA_STATESENTRY._options = None
  _WORKORDERDATA_STATESENTRY._serialized_options = b'8\001'
  _WORKITEMSTATE_STATEVALUESENTRY._options = None
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_options = b'8\001'
  _WORKORDERDATA._serialized_start=75
  _WORKORDERDATA._serialized_end=390
  _WORKORDERDATA_METADATAENTRY._serialized_start=253
  _WORKORDERDATA_METADATAENTRY._serialized_end=300
  _WORKORDERDATA_STATESENTRY._serialized_start=302
  _WORKORDERDATA_STATESENTRY._serialized_end=390
  _WORKITEMSTATE._serialized_start=393
  _WORKITEMSTATE._serialized_end=558
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_start=508
  _WORKITEMSTATE_STATEVALUESENTRY._serialized_end=558
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Postprocessing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(buffers/protobuf/nn/Postprocessing.proto\x12\"buffers.protobuf.nn.postprocessing\"#\n\x10RawTensorsOutput\x12\x0f\n\x07tensors\x18\x01 \x03(\t\"=\n\x0eStandardOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\"w\n\x1aInstanceSegmentationOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\x12\x16\n\x0e\x63lasses_tensor\x18\x03 \x01(\t\x12\x14\n\x0cmasks_tensor\x18\x04 \x01(\t\"W\n\x0e\x41nchoredOutput\x12\x16\n\x0e\x61nchors_tensor\x18\x01 \x01(\t\x12\x16\n\x0eoffsets_tensor\x18\x02 \x01(\t\x12\x15\n\rscores_tensor\x18\x03 \x01(\t\"S\n\x0c\x44irectOutput\x12\x14\n\x0c\x62oxes_tensor\x18\x01 \x01(\t\x12\x15\n\rscores_tensor\x18\x02 \x01(\t\x12\x16\n\x0e\x63lasses_tensor\x18\x03 \x01(\t\"4\n\nYoloOutput\x12\x15\n\routput_tensor\x18\x01 \x01(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\x02\"7\n\x0cYoloV3Output\x12\x16\n\x0eoutput_tensors\x18\x01 \x03(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\x02\"\xe5\x04\n\x0ePostProcessing\x12M\n\x0f\x61nchored_output\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.AnchoredOutputH\x00\x12I\n\rdirect_output\x18\x02 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.DirectOutputH\x00\x12\x45\n\x0byolo_output\x18\x03 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.YoloOutputH\x00\x12I\n\ryolov3_output\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.YoloV3OutputH\x00\x12N\n\x0etensors_output\x18\x05 \x01(\x0b\x32\x34.buffers.protobuf.nn.postprocessing.RawTensorsOutputH\x00\x12M\n\x0fstandard_output\x18\x06 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.StandardOutputH\x00\x12\x66\n\x1cinstance_segmentation_output\x18\x07 \x01(\x0b\x32>.buffers.protobuf.nn.postprocessing.InstanceSegmentationOutputH\x00\x12\x18\n\x10\x65xpand_batch_dim\x18\x0f \x01(\x08\x42\x06\n\x04type\"^\n\x0fPostProcessings\x12K\n\x0fpostprocessings\x18\x01 \x03(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.PostProcessing\"\xfc\x01\n\x0cLabelsOutput\x12\x46\n\x06labels\x18\x01 \x03(\x0b\x32\x36.buffers.protobuf.nn.postprocessing.LabelsOutput.Label\x12\x11\n\texclusive\x18\x02 \x01(\x08\x12\x45\n\x03roi\x18\x03 \x01(\x0e\x32\x38.buffers.protobuf.nn.postprocessing.LabelsOutput.ROIType\x1a!\n\x05Label\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"\'\n\x07ROIType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x42\x42OX\x10\x01\x12\x08\n\x04MASK\x10\x02\" \n\nTextOutput\x12\x12\n\ncharacters\x18\x01 \x03(\t\"\xeb\x01\n\x07Outputs\x12\x46\n\x07outputs\x18\x01 \x03(\x0b\x32\x35.buffers.protobuf.nn.postprocessing.Outputs.OutputMix\x1a\x97\x01\n\tOutputMix\x12\x42\n\x06labels\x18\x01 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.LabelsOutputH\x00\x12>\n\x04text\x18\x02 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.TextOutputH\x00\x42\x06\n\x04type\";\n\x0e\x43lassification\x12\x15\n\routput_tensor\x18\x01 \x01(\t\x12\x12\n\nthresholds\x18\x02 \x03(\x01\"\xcd\x04\n\tDetection\x12K\n\noutput_mix\x18\x01 \x01(\x0b\x32\x37.buffers.protobuf.nn.postprocessing.Detection.OutputMix\x12\x12\n\nthresholds\x18\x02 \x03(\x01\x12\x15\n\rnms_threshold\x18\x03 \x01(\x01\x12\x19\n\x11\x64iscard_threshold\x18\x04 \x01(\x01\x12\x1c\n\x14normalize_wrt_tensor\x18\x05 \x01(\t\x1a\x8e\x03\n\tOutputMix\x12M\n\x0f\x61nchored_output\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.AnchoredOutputH\x00\x12I\n\rdirect_output\x18\x02 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.DirectOutputH\x00\x12\x45\n\x0byolo_output\x18\x03 \x01(\x0b\x32..buffers.protobuf.nn.postprocessing.YoloOutputH\x00\x12I\n\ryolov3_output\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.YoloV3OutputH\x00\x12M\n\x0fstandard_output\x18\x05 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.StandardOutputH\x00\x42\x06\n\x04type\"\x05\n\x03OCR\"\x8a\x02\n\x0cSegmentation\x12N\n\noutput_mix\x18\x01 \x01(\x0b\x32:.buffers.protobuf.nn.postprocessing.Segmentation.OutputMix\x12\x12\n\nthresholds\x18\x02 \x03(\x01\x12\x19\n\x11\x64iscard_threshold\x18\x03 \x01(\x01\x1a{\n\tOutputMix\x12\x66\n\x1cinstance_segmentation_output\x18\x01 \x01(\x0b\x32>.buffers.protobuf.nn.postprocessing.InstanceSegmentationOutputH\x00\x42\x06\n\x04type\"\xcb\x03\n\x19PostprocessingsDeprecated\x12r\n\x0fpostprocessings\x18\x01 \x03(\x0b\x32Y.buffers.protobuf.nn.postprocessing.PostprocessingsDeprecated.PostprocessingMixDeprecated\x1a\xb9\x02\n\x1bPostprocessingMixDeprecated\x12L\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32\x32.buffers.protobuf.nn.postprocessing.ClassificationH\x00\x12\x42\n\tdetection\x18\x02 \x01(\x0b\x32-.buffers.protobuf.nn.postprocessing.DetectionH\x00\x12\x36\n\x03ocr\x18\x03 \x01(\x0b\x32\'.buffers.protobuf.nn.postprocessing.OCRH\x00\x12H\n\x0csegmentation\x18\x04 \x01(\x0b\x32\x30.buffers.protobuf.nn.postprocessing.SegmentationH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Postprocessing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RAWTENSORSOUTPUT._serialized_start=80
  _RAWTENSORSOUTPUT._serialized_end=115
  _STANDARDOUTPUT._serialized_start=117
  _STANDARDOUTPUT._serialized_end=178
  _INSTANCESEGMENTATIONOUTPUT._serialized_start=180
  _INSTANCESEGMENTATIONOUTPUT._serialized_end=299
  _ANCHOREDOUTPUT._serialized_start=301
  _ANCHOREDOUTPUT._serialized_end=388
  _DIRECTOUTPUT._serialized_start=390
  _DIRECTOUTPUT._serialized_end=473
  _YOLOOUTPUT._serialized_start=475
  _YOLOOUTPUT._serialized_end=527
  _YOLOV3OUTPUT._serialized_start=529
  _YOLOV3OUTPUT._serialized_end=584
  _POSTPROCESSING._serialized_start=587
  _POSTPROCESSING._serialized_end=1200
  _POSTPROCESSINGS._serialized_start=1202
  _POSTPROCESSINGS._serialized_end=1296
  _LABELSOUTPUT._serialized_start=1299
  _LABELSOUTPUT._serialized_end=1551
  _LABELSOUTPUT_LABEL._serialized_start=1477
  _LABELSOUTPUT_LABEL._serialized_end=1510
  _LABELSOUTPUT_ROITYPE._serialized_start=1512
  _LABELSOUTPUT_ROITYPE._serialized_end=1551
  _TEXTOUTPUT._serialized_start=1553
  _TEXTOUTPUT._serialized_end=1585
  _OUTPUTS._serialized_start=1588
  _OUTPUTS._serialized_end=1823
  _OUTPUTS_OUTPUTMIX._serialized_start=1672
  _OUTPUTS_OUTPUTMIX._serialized_end=1823
  _CLASSIFICATION._serialized_start=1825
  _CLASSIFICATION._serialized_end=1884
  _DETECTION._serialized_start=1887
  _DETECTION._serialized_end=2476
  _DETECTION_OUTPUTMIX._serialized_start=2078
  _DETECTION_OUTPUTMIX._serialized_end=2476
  _OCR._serialized_start=2478
  _OCR._serialized_end=2483
  _SEGMENTATION._serialized_start=2486
  _SEGMENTATION._serialized_end=2752
  _SEGMENTATION_OUTPUTMIX._serialized_start=2629
  _SEGMENTATION_OUTPUTMIX._serialized_end=2752
  _POSTPROCESSINGSDEPRECATED._serialized_start=2755
  _POSTPROCESSINGSDEPRECATED._serialized_end=3214
  _POSTPROCESSINGSDEPRECATED_POSTPROCESSINGMIXDEPRECATED._serialized_start=2901
  _POSTPROCESSINGSDEPRECATED_POSTPROCESSINGMIXDEPRECATED._serialized_end=3214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/cli/Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn import Command_pb2 as buffers_dot_protobuf_dot_nn_dot_Command__pb2
from deepomatic.rpc.buffers.protobuf.nn import Result_pb2 as buffers_dot_protobuf_dot_nn_dot_Result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"buffers/protobuf/cli/Message.proto\x12\x19\x62uffers.protobuf.deepocli\x1a!buffers/protobuf/nn/Command.proto\x1a buffers/protobuf/nn/Result.proto\"q\n\x07\x43ommand\x12\x34\n\x0b\x63ommand_mix\x18\x01 \x01(\x0b\x32\x1f.buffers.protobuf.nn.CommandMix\x12\x30\n\tinput_mix\x18\x02 \x01(\x0b\x32\x1d.buffers.protobuf.nn.InputMix\"k\n\x07Message\x12\x33\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\".buffers.protobuf.deepocli.Command\x12+\n\x06result\x18\x02 \x01(\x0b\x32\x1b.buffers.protobuf.nn.Resultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.cli.Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMAND._serialized_start=134
  _COMMAND._serialized_end=247
  _MESSAGE._serialized_start=249
  _MESSAGE._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Error_pb2 as buffers_dot_protobuf_dot_common_dot_Error__pb2
from deepomatic.rpc.buffers.protobuf.nn.v07 import Results_pb2 as buffers_dot_protobuf_dot_nn_dot_v07_dot_Results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n buffers/protobuf/nn/Result.proto\x12\x13\x62uffers.protobuf.nn\x1a#buffers/protobuf/common/Error.proto\x1a%buffers/protobuf/nn/v07/Results.proto\"\xcf\x01\n\x06Result\x12/\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1e.buffers.protobuf.common.ErrorH\x00\x12\x43\n\rv07_inference\x18\x04 \x01(\x0b\x32*.buffers.protobuf.nn.v07.results.InferenceH\x00\x12G\n\x0fv07_recognition\x18\x05 \x01(\x0b\x32,.buffers.protobuf.nn.v07.results.RecognitionH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESULT._serialized_start=134
  _RESULT._serialized_end=341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/frameworks/Caffe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*buffers/protobuf/nn/frameworks/Caffe.proto\x12$buffers.protobuf.nn.frameworks.caffe\"\x1c\n\tBlobShape\x12\x0f\n\x03\x64im\x18\x01 \x03(\x03\x42\x02\x10\x01\"\xeb\x01\n\tBlobProto\x12>\n\x05shape\x18\x07 \x01(\x0b\x32/.buffers.protobuf.nn.frameworks.caffe.BlobShape\x12\x10\n\x04\x64\x61ta\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x10\n\x04\x64iff\x18\x06 \x03(\x02\x42\x02\x10\x01\x12\x17\n\x0b\x64ouble_data\x18\x08 \x03(\x01\x42\x02\x10\x01\x12\x17\n\x0b\x64ouble_diff\x18\t \x03(\x01\x42\x02\x10\x01\x12\x0e\n\x03num\x18\x01 \x01(\x05:\x01\x30\x12\x13\n\x08\x63hannels\x18\x02 \x01(\x05:\x01\x30\x12\x11\n\x06height\x18\x03 \x01(\x05:\x01\x30\x12\x10\n\x05width\x18\x04 \x01(\x05:\x01\x30')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.frameworks.Caffe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BLOBSHAPE.fields_by_name['dim']._options = None
  _BLOBSHAPE.fields_by_name['dim']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['data']._options = None
  _BLOBPROTO.fields_by_name['data']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['diff']._options = None
  _BLOBPROTO.fields_by_name['diff']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['double_data']._options = None
  _BLOBPROTO.fields_by_name['double_data']._serialized_options = b'\020\001'
  _BLOBPROTO.fields_by_name['double_diff']._options = None
  _BLOBPROTO.fields_by_name['double_diff']._serialized_options = b'\020\001'
  _BLOBSHAPE._serialized_start=84
  _BLOBSHAPE._serialized_end=112
  _BLOBPROTO._serialized_start=115
  _BLOBPROTO._serialized_end=350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&buffers/protobuf/nn/v07/Commands.proto\x12 buffers.protobuf.nn.v07.commands\"\x0b\n\tInference\"R\n\x0bRecognition\x12\x12\n\nversion_id\x18\x01 \x01(\x05\x12\x16\n\x0eshow_discarded\x18\x08 \x01(\x08\x12\x17\n\x0fmax_predictions\x18\t \x01(\x05\"\n\n\x08Workflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Commands_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INFERENCE._serialized_start=76
  _INFERENCE._serialized_end=87
  _RECOGNITION._serialized_start=89
  _RECOGNITION._serialized_end=171
  _WORKFLOW._serialized_start=173
  _WORKFLOW._serialized_end=183
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/v07/Inputs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.common import Image_pb2 as buffers_dot_protobuf_dot_common_dot_Image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$buffers/protobuf/nn/v07/Inputs.proto\x12\x1e\x62uffers.protobuf.nn.v07.inputs\x1a#buffers/protobuf/common/Image.proto\"\x9b\x01\n\nImageInput\x12\x0e\n\x06source\x18\x01 \x01(\x0c\x12+\n\x04\x62\x62ox\x18\x02 \x01(\x0b\x32\x1d.buffers.protobuf.common.BBox\x12/\n\x07polygon\x18\x03 \x03(\x0b\x32\x1e.buffers.protobuf.common.Point\x12\x1f\n\x17\x63rop_uniform_background\x18\x04 \x01(\x08\"\x9a\x01\n\x06Inputs\x12?\n\x06inputs\x18\x01 \x03(\x0b\x32/.buffers.protobuf.nn.v07.inputs.Inputs.InputMix\x1aO\n\x08InputMix\x12;\n\x05image\x18\x01 \x01(\x0b\x32*.buffers.protobuf.nn.v07.inputs.ImageInputH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.v07.Inputs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMAGEINPUT._serialized_start=110
  _IMAGEINPUT._serialized_end=265
  _INPUTS._serialized_start=268
  _INPUTS._serialized_end=422
  _INPUTS_INPUTMIX._serialized_start=343
  _INPUTS_INPUTMIX._serialized_end=422
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Preprocessing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'buffers/protobuf/nn/Preprocessing.proto\x12!buffers.protobuf.nn.preprocessing\")\n\nMeanTensor\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x02\"\xb4\x01\n\x15\x43onstantPreprocessing\x12\r\n\x05shape\x18\x01 \x03(\x05\x12L\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32>.buffers.protobuf.nn.preprocessing.ConstantPreprocessing.Entry\x1a>\n\x05\x45ntry\x12\x15\n\x0b\x66loat_entry\x18\x01 \x01(\x02H\x00\x12\x16\n\x0cstring_entry\x18\x02 \x01(\tH\x00\x42\x06\n\x04type\"\xff\x04\n\x12ImagePreprocessing\x12\x11\n\tmean_file\x18\x01 \x01(\t\x12[\n\x0e\x63olor_channels\x18\x02 \x01(\x0e\x32\x43.buffers.protobuf.nn.preprocessing.ImagePreprocessing.ColorChannels\x12]\n\x0f\x64imension_order\x18\x03 \x01(\x0e\x32\x44.buffers.protobuf.nn.preprocessing.ImagePreprocessing.DimensionOrder\x12U\n\x0bresize_type\x18\x04 \x01(\x0e\x32@.buffers.protobuf.nn.preprocessing.ImagePreprocessing.ResizeType\x12\x13\n\x0btarget_size\x18\x05 \x01(\t\x12\x15\n\rpixel_scaling\x18\x06 \x01(\x02\x12Q\n\tdata_type\x18\x07 \x01(\x0e\x32>.buffers.protobuf.nn.preprocessing.ImagePreprocessing.DataType\"9\n\nResizeType\x12\x0b\n\x07NETWORK\x10\x00\x12\x08\n\x04\x46ILL\x10\x02\x12\x08\n\x04\x43ROP\x10\x03\x12\n\n\x06SQUASH\x10\x04\"+\n\rColorChannels\x12\x07\n\x03\x42GR\x10\x00\x12\x07\n\x03RGB\x10\x01\x12\x08\n\x04GRAY\x10\x02\"8\n\x0e\x44imensionOrder\x12\x08\n\x04NCHW\x10\x00\x12\x08\n\x04NCWH\x10\x01\x12\x08\n\x04NHWC\x10\x02\x12\x08\n\x04NWHC\x10\x03\"\"\n\x08\x44\x61taType\x12\x0b\n\x07\x46LOAT32\x10\x00\x12\t\n\x05UINT8\x10\x01\"\xb0\x01\n\x10PreprocessingMix\x12L\n\x08\x63onstant\x18\x01 \x01(\x0b\x32\x38.buffers.protobuf.nn.preprocessing.ConstantPreprocessingH\x00\x12\x46\n\x05image\x18\x02 \x01(\x0b\x32\x35.buffers.protobuf.nn.preprocessing.ImagePreprocessingH\x00\x42\x06\n\x04type\"t\n\rPreprocessing\x12\x13\n\x0btensor_name\x18\x01 \x01(\t\x12N\n\x11preprocessing_mix\x18\x02 \x01(\x0b\x32\x33.buffers.protobuf.nn.preprocessing.PreprocessingMix\"j\n\x0ePreprocessings\x12@\n\x06inputs\x18\x01 \x03(\x0b\x32\x30.buffers.protobuf.nn.preprocessing.Preprocessing\x12\x16\n\x0e\x62\x61tched_output\x18\x02 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Preprocessing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEANTENSOR._serialized_start=78
  _MEANTENSOR._serialized_end=119
  _CONSTANTPREPROCESSING._serialized_start=122
  _CONSTANTPREPROCESSING._serialized_end=302
  _CONSTANTPREPROCESSING_ENTRY._serialized_start=240
  _CONSTANTPREPROCESSING_ENTRY._serialized_end=302
  _IMAGEPREPROCESSING._serialized_start=305
  _IMAGEPREPROCESSING._serialized_end=944
  _IMAGEPREPROCESSING_RESIZETYPE._serialized_start=748
  _IMAGEPREPROCESSING_RESIZETYPE._serialized_end=805
  _IMAGEPREPROCESSING_COLORCHANNELS._serialized_start=807
  _IMAGEPREPROCESSING_COLORCHANNELS._serialized_end=850
  _IMAGEPREPROCESSING_DIMENSIONORDER._serialized_start=852
  _IMAGEPREPROCESSING_DIMENSIONORDER._serialized_end=908
  _IMAGEPREPROCESSING_DATATYPE._serialized_start=910
  _IMAGEPREPROCESSING_DATATYPE._serialized_end=944
  _PREPROCESSINGMIX._serialized_start=947
  _PREPROCESSINGMIX._serialized_end=1123
  _PREPROCESSING._serialized_start=1125
  _PREPROCESSING._serialized_end=1241
  _PREPROCESSINGS._serialized_start=1243
  _PREPROCESSINGS._serialized_end=1349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/nn/Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.nn import Command_pb2 as buffers_dot_protobuf_dot_nn_dot_Command__pb2
from deepomatic.rpc.buffers.protobuf.nn import Result_pb2 as buffers_dot_protobuf_dot_nn_dot_Result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!buffers/protobuf/nn/Message.proto\x12\x13\x62uffers.protobuf.nn\x1a!buffers/protobuf/nn/Command.proto\x1a buffers/protobuf/nn/Result.proto\"q\n\x07Message\x12/\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x1c.buffers.protobuf.nn.CommandH\x00\x12-\n\x06result\x18\x02 \x01(\x0b\x32\x1b.buffers.protobuf.nn.ResultH\x00\x42\x06\n\x04typeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.nn.Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=127
  _MESSAGE._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buffers/protobuf/workflows/WorkflowExecution.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepomatic.rpc.buffers.protobuf.workflows import Workflow_pb2 as buffers_dot_protobuf_dot_workflows_dot_Workflow__pb2
from deepomatic.rpc.buffers.protobuf.common import Error_pb2 as buffers_dot_protobuf_dot_common_dot_Error__pb2
from deepomatic.rpc.buffers.protobuf.workflows import WorkOrder_pb2 as buffers_dot_protobuf_dot_workflows_dot_WorkOrder__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2buffers/protobuf/workflows/WorkflowExecution.proto\x12\x1a\x62uffers.protobuf.workflows\x1a)buffers/protobuf/workflows/Workflow.proto\x1a#buffers/protobuf/common/Error.proto\x1a*buffers/protobuf/workflows/WorkOrder.proto\"\xb1\x05\n\x0fWorkflowRequest\x12Z\n\x10workflow_entries\x18\x01 \x03(\x0b\x32@.buffers.protobuf.workflows.WorkflowRequest.WorkflowEntriesEntry\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.buffers.protobuf.workflows.WorkflowRequest.MetadataEntry\x12\x1a\n\x12output_routing_key\x18\x03 \x01(\t\x12\x1d\n\x15return_flow_container\x18\x04 \x01(\x08\x12,\n$return_flow_container_without_images\x18\x05 \x01(\x08\x12:\n\x07wo_data\x18\x06 \x01(\x0b\x32).buffers.protobuf.workflows.WorkOrderData\x12\\\n\x11\x61nalysis_metadata\x18\x07 \x03(\x0b\x32\x41.buffers.protobuf.workflows.WorkflowRequest.AnalysisMetadataEntry\x12\x17\n\x0ftask_group_name\x18\x08 \x01(\t\x12\x12\n\nextra_data\x18\t \x01(\t\x1a[\n\x14WorkflowEntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Concept:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15\x41nalysisMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x02\n\x10WorkflowResponse\x12-\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1e.buffers.protobuf.common.Error\x12L\n\x08outcomes\x18\x02 \x03(\x0b\x32:.buffers.protobuf.workflows.WorkflowResponse.OutcomesEntry\x12\x41\n\x0e\x66low_container\x18\x03 \x01(\x0b\x32).buffers.protobuf.workflows.FlowContainer\x1aT\n\rOutcomesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.buffers.protobuf.workflows.Outcome:\x02\x38\x01\x32\xfc\x01\n\x10WorkflowExecutor\x12n\n\x0f\x45xecuteWorkflow\x12+.buffers.protobuf.workflows.WorkflowRequest\x1a,.buffers.protobuf.workflows.WorkflowResponse\"\x00\x12x\n\x15\x45xecuteWorkflowStream\x12+.buffers.protobuf.workflows.WorkflowRequest\x1a,.buffers.protobuf.workflows.WorkflowResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buffers.protobuf.workflows.WorkflowExecution_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._options = None
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST_METADATAENTRY._options = None
  _WORKFLOWREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._options = None
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_options = b'8\001'
  _WORKFLOWRESPONSE_OUTCOMESENTRY._options = None
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_options = b'8\001'
  _WORKFLOWREQUEST._serialized_start=207
  _WORKFLOWREQUEST._serialized_end=896
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_start=699
  _WORKFLOWREQUEST_WORKFLOWENTRIESENTRY._serialized_end=790
  _WORKFLOWREQUEST_METADATAENTRY._serialized_start=792
  _WORKFLOWREQUEST_METADATAENTRY._serialized_end=839
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_start=841
  _WORKFLOWREQUEST_ANALYSISMETADATAENTRY._serialized_end=896
  _WORKFLOWRESPONSE._serialized_start=899
  _WORKFLOWRESPONSE._serialized_end=1195
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_start=1111
  _WORKFLOWRESPONSE_OUTCOMESENTRY._serialized_end=1195
  _WORKFLOWEXECUTOR._serialized_start=1198
  _WORKFLOWEXECUTOR._serialized_end=1450
# @@protoc_insertion_point(module_scope)
